API Reference
=============

This section documents the BI-PASS Python API, auto-generated from source code docstrings.

.. toctree::
   :maxdepth: 2

   general_framework
   solar_production
   power_consumption
   config
   apps
